@@ -12,6 +12,7 @@ import signal
 import socket
 import sys
 import tempfile
+import traceback
 
 from gunicorn import http
 from gunicorn import util
@@ -24,9 +25,11 @@ class Worker(object):
         "HUP QUIT INT TERM TTIN TTOU USR1".split()
     )
 
-    def __init__(self, workerid, ppid, socket, app, timeout):
+    def __init__(self, workerid, ppid, socket, app, timeout,
+            debug=False):
         self.id = workerid
         self.ppid = ppid
+        self.debug = debug
         self.timeout = timeout / 2.0
         fd, tmpname = tempfile.mkstemp()
         self.tmp = os.fdopen(fd, "r+b")
@@ -114,8 +117,20 @@ class Worker(object):
     def handle(self, client, addr):
         util.close_on_exec(client)
         try:
-            req = http.HttpRequest(client, addr, self.address)
-            response = self.app(req.read(), req.start_response)
+            req = http.HttpRequest(client, addr, self.address, self.debug)
+            try:
+                response = self.app(req.read(), req.start_response)
+            except Exception, e:
+                exc = ''.join(traceback.format_exception(*sys.exc_info()))
+                msg = "<h1>Internal Server Error</h1><h2>wsgi error:</h2><pre>%s</pre>" % exc
+                util.writelines(client, 
+                ["HTTP/1.0 500 Internal Server Error\r\n",
+                "Connection: close\r\n",
+                "Content-type: text/html\r\n",
+                "Content-length: %s\r\n" % str(len(msg)),
+                "\r\n",
+                msg])
+                return 
             http.HttpResponse(client, response, req).send()
         except Exception, e:
             self.log.exception("Error processing request. [%s]" % str(e))    
